@@ -1,12 +1,12 @@
 package Log::ger::App;
 
-our $DATE = '2020-11-11'; # DATE
-our $VERSION = '0.018'; # VERSION
+use strict;
+use warnings;
 
-# IFUNBUILT
-# use strict;
-# use warnings;
-# END IFUNBUILT
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-24'; # DATE
+our $DIST = 'Log-ger-App'; # DIST
+our $VERSION = '0.019'; # VERSION
 
 our $DEBUG = defined($ENV{LOG_GER_APP_DEBUG}) ? $ENV{LOG_GER_APP_DEBUG} : 0;
 
@@ -126,6 +126,7 @@ sub import {
         );
         last if $olevel eq 'off';
         my $fmt =
+            ($ENV{LOG_ADD_LOCATION} ? '[file %F:%L] ': '').
             ($ENV{LOG_ADD_TIMESTAMP} ? '[%d] ': '').
             ($ENV{LOG_ADD_MEMORY_INFO} ? '[vmsize %_{vmsize}K] ': '').
             '%m';
@@ -222,7 +223,7 @@ Log::ger::App - An easy way to use Log::ger in applications
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -406,6 +407,12 @@ purposes.
 
 Used to set the default for C<$DEBUG>.
 
+=head2 LOG_ADD_LOCATION
+
+Boolean. Default to false. If set to true, will add location to the log:
+
+ [file /some/path.pm:123]
+
 =head2 LOG_ADD_TIMESTAMP
 
 Boolean. Default to false. If set to true, will add timestamps to the screen
@@ -541,7 +548,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
